# Supported Features

| Feature                       | v0 | v1 | Note |
|-------------------------------|----|----|------|
| Chunked Prefill               |    |    |      |
| Automatic Prefix Caching      |    | 🚧 |      |
| LoRA                          |    |    |      |
| Prompt Adapter                |    |    |      |
| Speculative Decoding          |    |    |      |
| Guided Decoding               |    |    |      |
| Pooling                       |    |    |      |
| Enc-dec                       |    |    |      |
| Multi Modality                |    |    |      |
| LogProbs                      | ✅ | ✅ |      |
| Prompt logProbs               | ✅ | ✅ |      |
| Async output                  |    |    |      |
| Multi step scheduler          |    |    |      |
| Best of                       |    |    |      |
| Beam search                   |    |    |      |
| Tensor Parallel               | ✅ | ✅ |      |
| Pipeline Parallel             |    |    |      |
| Expert Parallel               |    |    |      |
| Data Parallel                 |    |    |      |
| Prefill Decode Disaggregation |    |    |      |
| Quantization                  |    | ⚠️ |      |
| Graph Mode                    |    |    |      |
| Sleep Mode                    |    |    |      |

- ✅ Fully operational.
- ⚠️ Experimental support.
- 🚧 Under active development.
- 📅 Planned.
- ⛔ Not planned or deprecated.
